Package: DuoClustering2018
Type: Package
Title: Data, Clustering Results and Visualization Functions From Duò et
        al (2018)
Version: 1.28.0
Author: Angelo Duò, Charlotte Soneson
Maintainer: Angelo Duò <angelo.duo@icloud.com>
Description: Preprocessed experimental and simulated scRNA-seq data sets used 
    for evaluation of clustering methods for scRNA-seq data in 
    Duò et al (2018). Also contains results from applying several clustering 
    methods to each of the data sets, and functions for plotting method 
    performance.
License: GPL (>=2)
Encoding: UTF-8
biocViews: SingleCellData, ExperimentData
Imports: ExperimentHub, utils, magrittr, dplyr, tidyr, mclust, ggplot2,
        purrr, reshape2, viridis, ggthemes, stats, methods
Suggests: knitr, rmarkdown, BiocStyle, iSEE, scater,
        SingleCellExperiment, SummarizedExperiment, plyr
VignetteBuilder: knitr
RoxygenNote: 6.1.0
git_url: https://git.bioconductor.org/packages/DuoClustering2018
git_branch: RELEASE_3_22
git_last_commit: 3a6eb6f
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-11-06
NeedsCompilation: no
Packaged: 2025-11-06 16:17:47 UTC; biocbuild
