# DuoClustering2018
R package with data sets and clustering results from Duò et al (F1000Research 2018). See  https://doi.org/10.12688/F1000RESEARCH.15666.1 for the paper. The package is available from https://bioconductor.org/packages/DuoClustering2018.
To install the package use the following commands in R:
```
if (!requireNamespace("BiocManager", quietly=TRUE))
    install.packages("BiocManager")
BiocManager::install("DuoClustering2018", version = "devel")
```
